==> photoqt_4.4+ds.orig.tar.xz: photoqt-4.4+ds/cplusplus/header/pqc_providertheme.h <==
/**************************************************************************
 **                                                                      **
 ** Copyright (C) 2011-2024 Lukas Spies                                  **
 ** Contact: https://photoqt.org                                         **
 **                                                                      **
 ** This file is part of PhotoQt.                                        **
 **                                                                      **
 ** PhotoQt is free software: you can redistribute it and/or modify      **
 ** it under the terms of the GNU General Public License as published by **
 ** the Free Software Foundation, either version 2 of the License, or    **
 ** (at your option) any later version.                                  **
 **                                                                      **
 ** PhotoQt is distributed in the hope that it will be useful,           **
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of       **
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        **
 ** GNU General Public License for more details.                         **
 **                                                                      **
 ** You should have received a copy of the GNU General Public License    **
 ** along with PhotoQt. If not, see <http://www.gnu.org/licenses/>.      **
 **                                                                      **
 **************************************************************************/

#ifndef PQCPROVIDERTHEME_H
#define PQCPROVIDERTHEME_H

#include <QQuickImageProvider>

class PQCProviderSVG;

class PQCProviderTheme : public QQuickImageProvider {

public:
    explicit PQCProviderTheme();
    ~PQCProviderTheme();

    QImage requestImage(const QString &icon, QSize *, const QSize &requestedSize);

private:
    PQCProviderSVG *svg;

};

#endif // IMAGEPROVIDERICON_H

==> photoqt_5.1+ds.orig.tar.xz: photoqt-5.1+ds/cplusplus/header/pqc_providertheme.h <==
/**************************************************************************
 **                                                                      **
 ** Copyright (C) 2011-2026 Lukas Spies                                  **
 ** Contact: https://photoqt.org                                         **
 **                                                                      **
 ** This file is part of PhotoQt.                                        **
 **                                                                      **
 ** PhotoQt is free software: you can redistribute it and/or modify      **
 ** it under the terms of the GNU General Public License as published by **
 ** the Free Software Foundation, either version 2 of the License, or    **
 ** (at your option) any later version.                                  **
 **                                                                      **
 ** PhotoQt is distributed in the hope that it will be useful,           **
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of       **
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        **
 ** GNU General Public License for more details.                         **
 **                                                                      **
 ** You should have received a copy of the GNU General Public License    **
 ** along with PhotoQt. If not, see <http://www.gnu.org/licenses/>.      **
 **                                                                      **
 **************************************************************************/
#pragma once

#include <QQuickImageProvider>

class PQCProviderSVG;

class PQCProviderTheme : public QQuickImageProvider {

public:
    explicit PQCProviderTheme();
    ~PQCProviderTheme();

    QImage requestImage(const QString &icon, QSize *, const QSize &requestedSize);

private:
    PQCProviderSVG *svg;
    QString origTheme;
    QString origFallbackTheme;

};
